==> gcl-1.0.tgz: gcl-1.0/cmpnew/cmplam.h <==

static L1();
static L2();
static L3();
static object LI9();
static object LI12();
static L19();
static L20();
static L22();
#define VC1
#define VC2
#define VC3
static object LI4();
#define VMB4 register object *base=vs_top; object  V11 ,V8;
#define VMS4 vs_top += 4;
#define VMV4 vs_reserve(4);
#define VMR4(VMT4) vs_top=base ; return(VMT4);
static object LI5();
#define VMB5
#define VMS5
#define VMV5
#define VMR5(VMT5) return(VMT5);
static object LI6();
#define VMB6 register object *base=vs_top;
#define VMS6  register object *sup=vs_top+1;vs_top=sup;
#define VMV6 vs_reserve(1);
#define VMR6(VMT6) vs_top=base ; return(VMT6);
static object LI7();
#define VMB7
#define VMS7
#define VMV7
#define VMR7(VMT7) return(VMT7);
static object LI8();
#define VMB8 object  V34 ,V33 ,V32 ,V31;
#define VMS8
#define VMV8
#define VMR8(VMT8) return(VMT8);
static object LI9();
#define VMB9 register object *base=vs_top; object  V125 ,V124 ,V122 ,V121 ,V118 ,V117 ,V114 ,V113 ,V112 ,V111 ,V107 ,V106 ,V105 ,V104 ,V101 ,V100 ,V99 ,V98 ,V96 ,V87 ,V86 ,V85 ,V84 ,V80 ,V79 ,V78 ,V75 ,V74 ,V73 ,V71 ,V70 ,V69 ,V62 ,V61; object Vcs[2];
#define VMS9  register object *sup=vs_top+4;vs_top=sup;
#define VMV9 vs_reserve(4);
#define VMR9(VMT9) vs_top=base ; return(VMT9);
static object LI10();
#define VMB10 register object *base=vs_top; object  V160 ,V155 ,V154 ,V151 ,V150;
#define VMS10 vs_top += 3;
#define VMV10 vs_reserve(3);
#define VMR10(VMT10) vs_top=base ; return(VMT10);
static object LI11();
#define VMB11 register object *base=vs_top;
#define VMS11  register object *sup=vs_top+1;vs_top=sup;
#define VMV11 vs_reserve(1);
#define VMR11(VMT11) vs_top=base ; return(VMT11);
static object LI12();
#define VMB12 register object *base=vs_top; object  V174; object Vcs[3];
#define VMS12 vs_top += 3;
#define VMV12 vs_reserve(3);
#define VMR12(VMT12) vs_top=base ; return(VMT12);
static object LI13();
#define VMB13 register object *base=vs_top; object  V217 ,V212 ,V211 ,V209 ,V208 ,V205 ,V204 ,V201 ,V200 ,V199 ,V196 ,V193 ,V192; GEN  V191= 0,V191alloc ,V190= 0,V190alloc; object  V189;
#define VMS13  register object *sup=vs_top+11;vs_top=sup;
#define VMV13 vs_reserve(11);
#define VMR13(VMT13) vs_top=base ; return(VMT13);
static object LI15();
#define VMB14 register object *base=vs_top; object  V277 ,V276 ,V275 ,V268 ,V266 ,V263 ,V260 ,V259; GEN  V258= 0,V258alloc ,V257= 0,V257alloc; object  V256 ,V255 ,V252 ,V251 ,V248 ,V247 ,V244 ,V243 ,V242 ,V239 ,V236;
#define VMS14  register object *sup=vs_top+14;vs_top=sup;
#define VMV14 vs_reserve(14);
#define VMR14(VMT14) vs_top=base ; return(VMT14);
static object LI17();
#define VMB15
#define VMS15
#define VMV15
#define VMR15(VMT15) return(VMT15);
static object LI18();
#define VMB16 register object *base=vs_top; object  V307 ,V304;
#define VMS16  register object *sup=vs_top+8;vs_top=sup;
#define VMV16 vs_reserve(8);
#define VMR16(VMT16) vs_top=base ; return(VMT16);
#define VC17 object  V359 ,V357 ,V356 ,V355 ,V350 ,V349 ,V348 ,V342 ,V341 ,V333 ,V332 ,V331;
#define VC18
static object LI21();
#define VMB19
#define VMS19
#define VMV19
#define VMR19(VMT19) return(VMT19);
#define VC20 object  V374 ,V373;
static object LI23();
#define VMB21 register object *base=vs_top;
#define VMS21 vs_top += 2;
#define VMV21 vs_reserve(2);
#define VMR21(VMT21) vs_top=base ; return(VMT21);
static object LI24();
#define VMB22 object  V389;
#define VMS22
#define VMV22
#define VMR22(VMT22) return(VMT22);
static object LI25();
#define VMB23 register object *base=vs_top; object  V420 ,V417 ,V416 ,V415 ,V414 ,V410 ,V409 ,V408 ,V407 ,V404 ,V403;
#define VMS23 vs_top += 11;
#define VMV23 vs_reserve(11);
#define VMR23(VMT23) vs_top=base ; return(VMT23);
static object LI26();
#define VMB24
#define VMS24
#define VMV24
#define VMR24(VMT24) return(VMT24);
static object LI27();
#define VMB25 register object *base=vs_top; object  V438 ,V437;
#define VMS25 vs_top += 4;
#define VMV25 vs_reserve(4);
#define VMR25(VMT25) vs_top=base ; return(VMT25);
static L16();
#define VC26
static L14();
#define VC27
#define VM27 2
#define VM26 2
#define VM25 4
#define VM24 0
#define VM23 11
#define VM22 0
#define VM21 2
#define VM20 6
#define VM19 0
#define VM18 8
#define VM17 8
#define VM16 8
#define VM15 0
#define VM14 14
#define VM13 11
#define VM12 3
#define VM11 1
#define VM10 3
#define VM9 4
#define VM8 0
#define VM7 0
#define VM6 1
#define VM5 0
#define VM4 4
#define VM3 4
#define VM2 4
#define VM1 4
static char * VVi[124]={
#define Cdata VV[123]
(char *)(L1),
(char *)(L2),
(char *)(L3),
(char *)(LI4),
(char *)(LI5),
(char *)(LI6),
(char *)(LI7),
(char *)(LI8),
(char *)(LI9),
(char *)(LI10),
(char *)(LI11),
(char *)(LI12),
(char *)(LI13),
(char *)(LI15),
(char *)(LI17),
(char *)(LI18),
(char *)(L19),
(char *)(L20),
(char *)(LI21),
(char *)(L22),
(char *)(LI23),
(char *)(LI24),
(char *)(LI25),
(char *)(LI26),
(char *)(LI27)
};
#define VV ((object *)VVi)
static  LnkT122() ;
static  (*Lnk122)() = LnkT122;
static object  LnkTLI121() ;
static object  (*LnkLI121)() = LnkTLI121;
static object  LnkTLI120() ;
static object  (*LnkLI120)() = LnkTLI120;
static object  LnkTLI119() ;
static object  (*LnkLI119)() = LnkTLI119;
static object  LnkTLI118() ;
static object  (*LnkLI118)() = LnkTLI118;
static object  LnkTLI117() ;
static object  (*LnkLI117)() = LnkTLI117;
static object  LnkTLI116() ;
static object  (*LnkLI116)() = LnkTLI116;
static object  LnkTLI115() ;
static object  (*LnkLI115)() = LnkTLI115;
static object  LnkTLI114() ;
static object  (*LnkLI114)() = LnkTLI114;
static object  LnkTLI113() ;
static object  (*LnkLI113)() = LnkTLI113;
static  LnkT112() ;
static  (*Lnk112)() = LnkT112;
static  LnkT111() ;
static  (*Lnk111)() = LnkT111;
static  LnkT110() ;
static  (*Lnk110)() = LnkT110;
static object  LnkTLI109() ;
static object  (*LnkLI109)() = LnkTLI109;
static object  LnkTLI108() ;
static object  (*LnkLI108)() = LnkTLI108;
static  LnkT107() ;
static  (*Lnk107)() = LnkT107;
static object  LnkTLI106() ;
static object  (*LnkLI106)() = LnkTLI106;
static object  LnkTLI105() ;
static object  (*LnkLI105)() = LnkTLI105;
static object  LnkTLI104() ;
static object  (*LnkLI104)() = LnkTLI104;
static object  LnkTLI103() ;
static object  (*LnkLI103)() = LnkTLI103;
static object  LnkTLI102() ;
static object  (*LnkLI102)() = LnkTLI102;
static object  LnkTLI101() ;
static object  (*LnkLI101)() = LnkTLI101;
static object  LnkTLI100() ;
static object  (*LnkLI100)() = LnkTLI100;
static object  LnkTLI99() ;
static object  (*LnkLI99)() = LnkTLI99;
static object  LnkTLI98() ;
static object  (*LnkLI98)() = LnkTLI98;
static object  LnkTLI97() ;
static object  (*LnkLI97)() = LnkTLI97;
static object  LnkTLI96() ;
static object  (*LnkLI96)() = LnkTLI96;
static object  LnkTLI95() ;
static object  (*LnkLI95)() = LnkTLI95;
static object  LnkTLI94() ;
static object  (*LnkLI94)() = LnkTLI94;
static object  LnkTLI93() ;
static object  (*LnkLI93)() = LnkTLI93;
static object  LnkTLI92() ;
static object  (*LnkLI92)() = LnkTLI92;
static object  LnkTLI91() ;
static object  (*LnkLI91)() = LnkTLI91;
static object  LnkTLI90() ;
static object  (*LnkLI90)() = LnkTLI90;
static object  LnkTLI89() ;
static object  (*LnkLI89)() = LnkTLI89;
static object  LnkTLI88() ;
static object  (*LnkLI88)() = LnkTLI88;
static  LnkT87() ;
static  (*Lnk87)() = LnkT87;
static object  LnkTLI86() ;
static object  (*LnkLI86)() = LnkTLI86;
static object  LnkTLI85() ;
static object  (*LnkLI85)() = LnkTLI85;
static object  LnkTLI84() ;
static object  (*LnkLI84)() = LnkTLI84;
static object  LnkTLI83() ;
static object  (*LnkLI83)() = LnkTLI83;
static object  LnkTLI82() ;
static object  (*LnkLI82)() = LnkTLI82;
static object  LnkTLI81() ;
static object  (*LnkLI81)() = LnkTLI81;
static object  LnkTLI80() ;
static object  (*LnkLI80)() = LnkTLI80;
static object  LnkTLI79() ;
static object  (*LnkLI79)() = LnkTLI79;

==> gcl-2.0.tgz: gcl-2.0/cmpnew/cmplam.h <==

static L1();
static L2();
static L3();
static object LI9();
static object LI12();
static L19();
static L20();
static L22();
#define VC1
#define VC2
#define VC3
static object LI4();
#define VMB4 register object *base=vs_top; object  V11 ,V8;
#define VMS4 vs_top += 4;
#define VMV4 vs_reserve(4);
#define VMR4(VMT4) vs_top=base ; return(VMT4);
static object LI5();
#define VMB5
#define VMS5
#define VMV5
#define VMR5(VMT5) return(VMT5);
static object LI6();
#define VMB6 register object *base=vs_top;
#define VMS6  register object *sup=vs_top+1;vs_top=sup;
#define VMV6 vs_reserve(1);
#define VMR6(VMT6) vs_top=base ; return(VMT6);
static object LI7();
#define VMB7
#define VMS7
#define VMV7
#define VMR7(VMT7) return(VMT7);
static object LI8();
#define VMB8 object  V34 ,V33 ,V32 ,V31;
#define VMS8
#define VMV8
#define VMR8(VMT8) return(VMT8);
static object LI9();
#define VMB9 register object *base=vs_top; object  V125 ,V124 ,V122 ,V121 ,V118 ,V117 ,V114 ,V113 ,V112 ,V111 ,V107 ,V106 ,V105 ,V104 ,V101 ,V100 ,V99 ,V98 ,V96 ,V87 ,V86 ,V85 ,V84 ,V80 ,V79 ,V78 ,V75 ,V74 ,V73 ,V71 ,V70 ,V69 ,V62 ,V61; object Vcs[2];
#define VMS9  register object *sup=vs_top+4;vs_top=sup;
#define VMV9 vs_reserve(4);
#define VMR9(VMT9) vs_top=base ; return(VMT9);
static object LI10();
#define VMB10 register object *base=vs_top; object  V161 ,V156 ,V155 ,V152 ,V151;
#define VMS10 vs_top += 3;
#define VMV10 vs_reserve(3);
#define VMR10(VMT10) vs_top=base ; return(VMT10);
static object LI11();
#define VMB11 register object *base=vs_top;
#define VMS11  register object *sup=vs_top+1;vs_top=sup;
#define VMV11 vs_reserve(1);
#define VMR11(VMT11) vs_top=base ; return(VMT11);
static object LI12();
#define VMB12 register object *base=vs_top; object  V175; object Vcs[3];
#define VMS12 vs_top += 3;
#define VMV12 vs_reserve(3);
#define VMR12(VMT12) vs_top=base ; return(VMT12);
static object LI13();
#define VMB13 register object *base=vs_top; object  V218 ,V213 ,V212 ,V210 ,V209 ,V206 ,V205 ,V202 ,V201 ,V200 ,V197 ,V194 ,V193 ,V192 ,V191 ,V190;
#define VMS13  register object *sup=vs_top+11;vs_top=sup;
#define VMV13 vs_reserve(11);
#define VMR13(VMT13) vs_top=base ; return(VMT13);
static object LI15();
#define VMB14 register object *base=vs_top; object  V278 ,V277 ,V276 ,V269 ,V267 ,V264 ,V261 ,V260 ,V259 ,V258 ,V257 ,V256 ,V253 ,V252 ,V249 ,V248 ,V245 ,V244 ,V243 ,V240 ,V237;
#define VMS14  register object *sup=vs_top+14;vs_top=sup;
#define VMV14 vs_reserve(14);
#define VMR14(VMT14) vs_top=base ; return(VMT14);
static object LI17();
#define VMB15
#define VMS15
#define VMV15
#define VMR15(VMT15) return(VMT15);
static object LI18();
#define VMB16 register object *base=vs_top; object  V308 ,V305;
#define VMS16  register object *sup=vs_top+8;vs_top=sup;
#define VMV16 vs_reserve(8);
#define VMR16(VMT16) vs_top=base ; return(VMT16);
#define VC17 object  V360 ,V358 ,V357 ,V356 ,V351 ,V350 ,V349 ,V343 ,V342 ,V334 ,V333 ,V332;
#define VC18
static object LI21();
#define VMB19
#define VMS19
#define VMV19
#define VMR19(VMT19) return(VMT19);
#define VC20 object  V375 ,V374;
static object LI23();
#define VMB21 register object *base=vs_top;
#define VMS21 vs_top += 2;
#define VMV21 vs_reserve(2);
#define VMR21(VMT21) vs_top=base ; return(VMT21);
static object LI24();
#define VMB22 object  V390;
#define VMS22
#define VMV22
#define VMR22(VMT22) return(VMT22);
static object LI25();
#define VMB23 register object *base=vs_top; object  V421 ,V418 ,V417 ,V416 ,V415 ,V411 ,V410 ,V409 ,V408 ,V405 ,V404;
#define VMS23 vs_top += 11;
#define VMV23 vs_reserve(11);
#define VMR23(VMT23) vs_top=base ; return(VMT23);
static object LI26();
#define VMB24
#define VMS24
#define VMV24
#define VMR24(VMT24) return(VMT24);
static object LI27();
#define VMB25 register object *base=vs_top; object  V439 ,V438;
#define VMS25 vs_top += 4;
#define VMV25 vs_reserve(4);
#define VMR25(VMT25) vs_top=base ; return(VMT25);
static L16();
#define VC26
static L14();
#define VC27
#define VM27 2
#define VM26 2
#define VM25 4
#define VM24 0
#define VM23 11
#define VM22 0
#define VM21 2
#define VM20 6
#define VM19 0
#define VM18 8
#define VM17 8
#define VM16 8
#define VM15 0
#define VM14 14
#define VM13 11
#define VM12 3
#define VM11 1
#define VM10 3
#define VM9 4
#define VM8 0
#define VM7 0
#define VM6 1
#define VM5 0
#define VM4 4
#define VM3 4
#define VM2 4
#define VM1 4
static char * VVi[130]={
#define Cdata VV[129]
(char *)(L1),
(char *)(L2),
(char *)(L3),
(char *)(LI4),
(char *)(LI5),
(char *)(LI6),
(char *)(LI7),
(char *)(LI8),
(char *)(LI9),
(char *)(LI10),
(char *)(LI11),
(char *)(LI12),
(char *)(LI13),
(char *)(LI15),
(char *)(LI17),
(char *)(LI18),
(char *)(L19),
(char *)(L20),
(char *)(LI21),
(char *)(L22),
(char *)(LI23),
(char *)(LI24),
(char *)(LI25),
(char *)(LI26),
(char *)(LI27)
};
#define VV ((object *)VVi)
static  LnkT128() ;
static  (*Lnk128)() = LnkT128;
static object  LnkTLI127() ;
static object  (*LnkLI127)() = LnkTLI127;
static object  LnkTLI126() ;
static object  (*LnkLI126)() = LnkTLI126;
static object  LnkTLI125() ;
static object  (*LnkLI125)() = LnkTLI125;
static object  LnkTLI124() ;
static object  (*LnkLI124)() = LnkTLI124;
static object  LnkTLI123() ;
static object  (*LnkLI123)() = LnkTLI123;
static object  LnkTLI122() ;
static object  (*LnkLI122)() = LnkTLI122;
static object  LnkTLI121() ;
static object  (*LnkLI121)() = LnkTLI121;
static object  LnkTLI120() ;
static object  (*LnkLI120)() = LnkTLI120;
static object  LnkTLI119() ;
static object  (*LnkLI119)() = LnkTLI119;
static  LnkT118() ;
static  (*Lnk118)() = LnkT118;
static  LnkT117() ;
static  (*Lnk117)() = LnkT117;
static  LnkT116() ;
static  (*Lnk116)() = LnkT116;
static  LnkT115() ;
static  (*Lnk115)() = LnkT115;
static  LnkT114() ;
static  (*Lnk114)() = LnkT114;
static object  LnkTLI113() ;
static object  (*LnkLI113)() = LnkTLI113;
static object  LnkTLI112() ;
static object  (*LnkLI112)() = LnkTLI112;
static  LnkT111() ;
static  (*Lnk111)() = LnkT111;
static object  LnkTLI110() ;
static object  (*LnkLI110)() = LnkTLI110;
static object  LnkTLI109() ;
static object  (*LnkLI109)() = LnkTLI109;
static object  LnkTLI108() ;
static object  (*LnkLI108)() = LnkTLI108;
static object  LnkTLI107() ;
static object  (*LnkLI107)() = LnkTLI107;
static object  LnkTLI106() ;
static object  (*LnkLI106)() = LnkTLI106;
static object  LnkTLI105() ;
static object  (*LnkLI105)() = LnkTLI105;
static object  LnkTLI104() ;
static object  (*LnkLI104)() = LnkTLI104;
static  LnkT103() ;
static  (*Lnk103)() = LnkT103;
static object  LnkTLI102() ;
static object  (*LnkLI102)() = LnkTLI102;
static object  LnkTLI101() ;
static object  (*LnkLI101)() = LnkTLI101;
static  LnkT100() ;
static  (*Lnk100)() = LnkT100;
static object  LnkTLI99() ;
static object  (*LnkLI99)() = LnkTLI99;
static object  LnkTLI98() ;
static object  (*LnkLI98)() = LnkTLI98;
static object  LnkTLI97() ;
static object  (*LnkLI97)() = LnkTLI97;
static object  LnkTLI96() ;
static object  (*LnkLI96)() = LnkTLI96;
static object  LnkTLI95() ;
static object  (*LnkLI95)() = LnkTLI95;
static  LnkT94() ;
static  (*Lnk94)() = LnkT94;
static object  LnkTLI93() ;
static object  (*LnkLI93)() = LnkTLI93;
static object  LnkTLI92() ;
static object  (*LnkLI92)() = LnkTLI92;
static object  LnkTLI91() ;
static object  (*LnkLI91)() = LnkTLI91;
static object  LnkTLI90() ;
static object  (*LnkLI90)() = LnkTLI90;
static object  LnkTLI89() ;
static object  (*LnkLI89)() = LnkTLI89;
static  LnkT88() ;
static  (*Lnk88)() = LnkT88;
static object  LnkTLI87() ;
static object  (*LnkLI87)() = LnkTLI87;
static object  LnkTLI86() ;
static object  (*LnkLI86)() = LnkTLI86;
static object  LnkTLI85() ;
static object  (*LnkLI85)() = LnkTLI85;
static object  LnkTLI84() ;
static object  (*LnkLI84)() = LnkTLI84;
static object  LnkTLI83() ;
static object  (*LnkLI83)() = LnkTLI83;
static object  LnkTLI82() ;
static object  (*LnkLI82)() = LnkTLI82;
static  LnkT81() ;
static  (*Lnk81)() = LnkT81;
static object  LnkTLI80() ;
static object  (*LnkLI80)() = LnkTLI80;
static object  LnkTLI79() ;
static object  (*LnkLI79)() = LnkTLI79;
